==> haskell-stm-hamt-1.2.1.1-96-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-hamt
version:              1.2.1.1
visibility:           public
id:                   stm-hamt-1.2.1.1-Gi9jaHvRBFT4jUoEqON9Xf
key:                  stm-hamt-1.2.1.1-Gi9jaHvRBFT4jUoEqON9Xf
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  ff414ee9e3da9660bd7bfb292697b67f
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1.1-Gi9jaHvRBFT4jUoEqON9Xf
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-FoBSiftVWcT4t8fgfUqevd
    focus-1.0.3.2-9UG6aWIJYQU1dpGJUMaXsH
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    list-t-1.0.5.7-Kce3kPVfPFH8fgauyBPiZn
    primitive-0.9.1.0-CwYB76NvKpqXNq7rVKe89
    primitive-extras-0.10.2.2-HvNbg0WFeY75u7f6Y1rBZv
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-hamt-1.2.1.1-119-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-hamt
version:              1.2.1.1
visibility:           public
id:                   stm-hamt-1.2.1.1-KFxLb5UNq5UDX5THhMshVc
key:                  stm-hamt-1.2.1.1-KFxLb5UNq5UDX5THhMshVc
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  d51c5cbaf736ce80a28f076a03a897cb
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1.1-KFxLb5UNq5UDX5THhMshVc
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-3yfE7C237Z7EaNudx50gxt
    focus-1.0.3.2-8hrsVfu9SCyGKwxAyYgRHl
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    list-t-1.0.5.7-GdSuNSaT7D1HbJEvfXY0bP
    primitive-0.9.1.0-1TuYyil4nabJdMHni5vWH
    primitive-extras-0.10.2.2-IzT8LqspGIn1ThfeqtLyNe
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
